@@ -1,16 +1,16 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = 'Christian Heider Nielsen'
-__doc__ = r'''
+__author__ = "Christian Heider Nielsen"
+__doc__ = r"""
 
            Created on 06-11-2020
-           '''
+           """
 
 import pathlib
 
 with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
-  __doc__ += this_init_file.read()
+    __doc__ += this_init_file.read()
 
 from .auto_dict import *
 from .named_ordered_dictionary import *
